@@ -143,7 +143,7 @@ gnome_print_dialog_init (GnomePrintDialog *gpd)
 	/* Empty */
 }
 
-void 
+static void 
 gnome_print_dialog_response_cb (GtkDialog *dialog,
 				gint response_id,
 				GnomePrintDialog *gpd)
@@ -538,9 +538,6 @@ gnome_print_dialog_construct_range_page (GnomePrintDialog *gpd, gint flags, gint
 	if (flags & GNOME_PRINT_RANGE_RANGE) {
 		GtkWidget *l, *sb;
 		GtkObject *a;
-		AtkRelationSet *relation_set;
-		AtkRelation *relation;
-		AtkObject *relation_targets[1];
 		AtkObject *atko;
 
 		hbox = gtk_hbox_new (FALSE, 3);
@@ -558,19 +555,9 @@ gnome_print_dialog_construct_range_page (GnomePrintDialog *gpd, gint flags, gint
 		gtk_box_pack_start (GTK_BOX (hbox), sb, FALSE, FALSE, 0);
 		gtk_label_set_mnemonic_widget ((GtkLabel *) l, sb);
 
-		/* Add a LABELLED_BY relation from the spinbutton to the label.
-		 */
 		atko = gtk_widget_get_accessible (sb);
 		atk_object_set_description (atko, _("Sets the start of the range of pages to be printed"));
 
-		relation_set = atk_object_ref_relation_set (atko);
-		relation_targets[0] = gtk_widget_get_accessible (l);
-		relation = atk_relation_new (relation_targets, 1,
-					     ATK_RELATION_LABELLED_BY);
-		atk_relation_set_add (relation_set, relation);
-		g_object_unref (G_OBJECT (relation));
-		g_object_unref (G_OBJECT (relation_set));
-
 		l = gtk_label_new_with_mnemonic (_("_To:"));
 		gtk_widget_show (l);
 		gtk_box_pack_start (GTK_BOX (hbox), l, FALSE, FALSE, 0);
@@ -583,18 +570,8 @@ gnome_print_dialog_construct_range_page (GnomePrintDialog *gpd, gint flags, gint
 		gtk_box_pack_start (GTK_BOX (hbox), sb, FALSE, FALSE, 0);
 		gtk_label_set_mnemonic_widget ((GtkLabel *) l, sb);
 
-		/* Add a LABELLED_BY relation from the spinbutton to the label.
-		 */
 		atko = gtk_widget_get_accessible (sb);
 		atk_object_set_description (atko, _("Sets the end of the range of pages to be printed"));
-
-		relation_set = atk_object_ref_relation_set (atko);
-		relation_targets[0] = gtk_widget_get_accessible (l);
-		relation = atk_relation_new (relation_targets, 1,
-					     ATK_RELATION_LABELLED_BY);
-		atk_relation_set_add (relation_set, relation);
-		g_object_unref (G_OBJECT (relation));
-		g_object_unref (G_OBJECT (relation_set));
 	}
 
 	gnome_print_dialog_construct_range_any (gpd, flags, hbox, currentlabel, rangelabel);
