@@ -670,16 +670,6 @@ create_preview_canvas (GnomePrintJobPreview *mp)
 	gtk_box_pack_start (GTK_BOX (mp->vbox), status, FALSE, FALSE, 3);
 	gtk_box_pack_start (GTK_BOX (mp->vbox), priv->scrolled_window, TRUE, TRUE, 0);
 
-	/* Add a LABELLED_BY relation from the page entry to the label. */
-	atko = gtk_widget_get_accessible (priv->page_entry);
-	relation_set = atk_object_ref_relation_set (atko);
-	relation_targets[0] = gtk_widget_get_accessible (l);
-	relation = atk_relation_new (relation_targets, 1,
-				     ATK_RELATION_LABELLED_BY);
-	atk_relation_set_add (relation_set, relation);
-	g_object_unref (G_OBJECT (relation));
-	g_object_unref (G_OBJECT (relation_set));
-
 	gtk_widget_show_all (mp->vbox);
 
 	gtk_widget_grab_focus (GTK_WIDGET (priv->canvas));
