@@ -163,7 +163,8 @@ gnome_print_unit_selector_init (GnomePrintUnitSelector *us)
 	us->abbr = FALSE;
 	us->plural = TRUE;
 
-	us->combo = gtk_combo_box_new ((GtkTreeModel *)gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER));
+	us->combo = gtk_combo_box_new_with_model (
+	    (GtkTreeModel *)gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER));
 	cell = gtk_cell_renderer_text_new ();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (us->combo), cell, TRUE);
 	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (us->combo), cell,
