@@ -122,14 +122,18 @@ gpa_printer_selector_rebuild_menu (GPAPrinterSelector *ps)
 {
 	GtkWidget *menu, *item;
 	GPANode *child;
-	GPANode *def;
+	GPANode *def = NULL;
 	gint pos = 0;
 	gint sel = -1;
 
+	g_return_if_fail (ps != NULL);
+
 	menu = gtk_menu_new ();
 	gtk_widget_show (menu);
 
-	def = GPA_REFERENCE_REFERENCE (GPA_CONFIG (ps->config)->printer);
+	if (ps->config != NULL)
+		def = GPA_REFERENCE_REFERENCE 
+			(GPA_CONFIG (ps->config)->printer);
 
 	child = gpa_node_get_child (ps->node, NULL);
 	while (child) {
@@ -160,7 +164,9 @@ gpa_printer_selector_rebuild_menu (GPAPrinterSelector *ps)
 	}
 	if (sel == -1) {
 		g_warning ("rebuild_menu_cb, could not set value of %s to %s",
-			   gpa_node_id (ps->node), gpa_node_id (def));
+			   gpa_node_id (ps->node), 
+			   (def == NULL) ? (const guchar *)"<NULL>" 
+			   : gpa_node_id (def));
 		sel = 0;
 	}
 
